Installation
============

The easiest ways to install **cgsmiles** is using pip:

.. code:: bash

   pip install git+https://github.com/gruenewald-lab/CGsmiles.git

In the future we will also distribute it through the Pypi
package index but that is currently not supported.

Note that the drawing module depends on the `scipy <https://scipy.org>`__ and `matplotlib <https://matplotlib.org>`__
packages. These need to be installed before the module can be used.
